Browser Pedals

## Usage:

### Control any video in a web browser with foot pedals - pause/play or jump back - even when the web browser is not in focus.

#### How to start controlling a video/audio with pedals:

Navigate to any Web site containing a video/audio (or to a local video/audio file: Firefox - "Alt" key, Chrome and Edge - "Ctrl+O" key).

To start controlling a video/audio with pedals, click "Play" button on the video with the mouse at least once.

To stop controlling the video/audio with pedals, click "Pause" button on the video with the mouse (not with pedals).
After that, you can start controlling any other video on the site by clicking it's "Play" button.

You may have to wait for about a minute before the program starts controlling the video, or click "Play" button on the video with the mouse several times.

#### How to control the video/audio with pedals:

To pause/play the video, press right pedal (or other pedal of your choice).

To jump back in the video, press left pedal (or other pedal of your choice).

## Как пользоваться:

### Управлять просмотром любого видео в веб-браузере с использованием ножных педалей - приостановить/продолжить или вернуться назад - даже когда веб-браузер находится не в фокусе.

#### Как начать управлять видео/аудио при помощи педалей:

Перейдите на любой веб-сайт, содержащий видео/аудио (или видео/аудио файл на компьютере: Firefox - клавиша "Alt", Chrome или Edge - клавиша "Ctrl+O").

Чтобы начать управлять видео/аудио при помощи педалей, кликните мышью кнопку "Воспроизведение" на видео хотя бы один раз.

Чтобы прекратить управлять данным видео/аудио при помощи педалей, кликните мышью кнопку "Пауза" на видео (не педалями).
После этого вы сможете начать управлять любым другим видео на сайте, кликнув мышью на его кнопке "Воспроизведение".

Иногда нужно подождать примерно минуту, пока программа начнет управлять выбранным видео, или кликнуть мышью кнопку "Воспроизведение" на видео несколько раз.

#### Как управлять видео/аудио при помощи педалей:

Чтобы приостановить/продолжить просмотр видео, нажмите правую педаль (или другую назначенную вами педаль).

Чтобы отмотать видео назад, нажмите левую педаль (или другую назначенную вами педаль).

## Editable options:

Application's editable data directory:

`application_data_directory`

## Редактируемые опции:

Директория редактируемых данных программы:

`application_data_directory`

### Change the program's options:

The following text file contains several options which users can edit to change the way the program behaves:

`options_text_file`

Available options:

browser: By default, the program opens Firefox browser. To use another browser, change the value of the browser option in the options file correspondingly. So far, the program was tested with Firefox, Chrome, and Edge browsers.

user_interface: By default, the program uses web browser as graphical user interface during pedals recognition. To use command line for pedals recognition, change the value of the user_interface option in the options file from "browser" to "command_line".

jump_back_sec: By default, pressing the "jump back" pedal rewinds the video 5 seconds back. To use another time jump, change the value of the jump_back_sec option in the options file correspondingly. It may be any number, possibly with a fractional part.

subtitles_to_clipboard: If this feature is enabled, every time user presses the pedal to Play the video and then presses the pedal to Pause it, subtitle timing data in SRT format is created for the video fragment just played (Play starts the subtitle, Pause ends the subtitle), and this SRT data is copied to the clipboard. Then it can be pasted to any text file before corresponding text fragment to make it an SRT subtitle. To enable this feature, set the value of the subtitles_to_clipboard option in the options file to 1. To disable this feature, set it to 0. To copy just timestamps to clipboard every time Pause pedal is pressed, instead of copying subtitle data (timestamp format is specified in the option called periodic_timestamp_format), set the value to -1.
Important: On Linux, to use this feature instal xclip: `sudo apt-get install xclip`

pause_period_sec: If this feature is enabled, the video/audio periodically pauses at certain time points in the video. When pressing Play after each such pause, current time point in the video/audio is copied to the clipboard, so the user can paste it into any text file. The string copied to the clipboard will have the format specified in the next option of the options file called periodic_timestamp_format. To enable this feature, set the value of the pause_period_sec option in the options file to desired time interval between pauses, in seconds, possibly with a fractional part. To disable this feature, set the value to 0.
Important: On Linux, to use this feature instal xclip: `sudo apt-get install xclip`

periodic_timestamp_format: If the feature pause_period_sec is enabled or the value of feature subtitles_to_clipboard is set to -1, this option specifies the format of the timestamp string which is copied to the clipboard during each pause. Set the value of the periodic_timestamp_format option in the options file to a Python format string, for example it can contain format elements such as {SS:04d} - in this string you can use variables SS (time in seconds), MM (time in minutes), hh (hours), mm (minutes), ss (seconds), uu (milliseconds).

### Browser data:

When this program opens a web browser, it uses a browser user's profile which is different from default profile used when the browser is opened standard way. All browser data (including user preferences, browser cache, history, bookmarks, installed extensions, etc.) used by web browsers when they are opened by this program are stored in the following location. If a profile here is deleted, a clean profile will be created instead:

`browser_profiles_directory`

### Изменение опций программы:

Следующий текстовый файл содержит ряд опций, которые пользователь может менять, чтобы корректировать поведение программы:

`options_text_file`

Имеющиеся опции:

browser: По умолчанию программа открывает браузер Firefox. Чтобы использовать другой браузер, в файле опций соответствующим образом поменяйте значение value опции browser. На данный момент программа тестировалась с браузерами Firefox, Chrome, и Edge.

user_interface: По умолчанию программа использует веб-браузер в качестве графического пользовательского интерфейса при распознавании педалей. Чтобы использовать командную строку для распознавания педалей, в файле опций поменяйте значение value опции user_interface с "browser" на "command_line".

jump_back_sec: По умолчанию при нажатии педали "возврат назад" видео отматывается назад на 5 секунд. Чтобы использовать другой временной скачок, в файле опций соответствующим образом поменяйте значение value опции jump_back_sec. Это может быть любое число, возможно с дробной частью.

subtitles_to_clipboard: Если данная опция включена, каждый раз, когда пользователь нажимает педаль для Воспроизведения видео, а затем нажимает педаль для Паузы видео, для только что проигранного фрагмента видео создаются временные параметры субтитра в SRT-формате (Воспроизведение начинает субтитр, Пауза заканчивает субтитр), и эти SRT-данные копируются в буфер обмена. После этого их можно вставить в любой текстовый файл перед соответствующим фрагментом текста, что превратит фрагмент в SRT-субтитр. Чтобы включить данную функцию, в файле опций установите значение value опции subtitles_to_clipboard равным 1. Чтобы отключить данную функцию, установите значение 0. Чтобы при каждом нажатии педали Пауза вместо данных субтитра в буфер обмена копировались просто текущие моменты времени видео (в формате, заданном в опции periodic_timestamp_format), установите значение -1.
Важно: В Linux, чтобы использовать данную функцию, установите xclip: `sudo apt-get install xclip`

pause_period_sec: Если данная опция включена, видео/аудио будет периодически вставать на паузу в определенные моменты текущего времени видео/аудио. При нажатии педали Воспроизведения после каждой такой паузы текущий момент времени видео/аудио будет скопирован в буфер обмена, чтобы пользователь мог вставить его в любой текстовый файл. Строка, скопированная в буфер обмена, будет иметь формат, заданный в следующей опции файла опций под названием periodic_timestamp_format. Чтобы включить данную функцию, в файле опций поменяйте значение value опции pause_period_sec на величину требуемого интервала времени между паузами, в секундах, возможно с дробной частью. Чтобы отключить данную функцию, установите значение 0.
Важно: В Linux, чтобы использовать данную функцию, установите xclip: `sudo apt-get install xclip`

periodic_timestamp_format: Если включена опция pause_period_sec или значение опции subtitles_to_clipboard установлено равным -1, то данная опция задает формат строки с текущим временем, которая копируется в буфер обмена после каждой паузы. В качестве значения поля value опции periodic_timestamp_format должна выступать строка формата из языка Python. Например, она может содержать элементы формата типа {SS:04d} - в этой строке можно использовать переменные SS (время в секундах), MM (время в минутах), hh (часы), mm (минуты), ss (секунды), uu (миллисекунды).

### Данные браузера:

Когда данная программа открывает веб-браузер, используется пользовательский профиль отличный от профиля, используемого по умолчанию при открытии браузера обычным образом. Все данные браузера (включая пользовательские настройки, кэш браузера, историю, закладки, установленные расширения, и т.п.), используемые веб-браузерами, когда они открываются данной программой, хранятся в следующей директории. Если профиль здесь удалить, вместо него будет создан чистый профиль:

`browser_profiles_directory`

### Install the Web Driver (optional):

The program comes with a pre-installed Web Driver for Firefox browser, so if you want to use Firefox it will work out of the box. However, if you want to use another browser like Chrome or Edge, you have to install corresponding Web Driver manually as described below. Also, in case of Chrome or Edge you will have to periodically upgrade the Web Driver to match the current version of automatically upgraded Chrome or Edge browser.

Install the Web Driver for the browser you want to use. The download links are on the site:

Download a Web Driver

Important:For all browsers except Firefox, the version of Web Driver file should match the current version of your browser.

Open the downloaded archive and extract the Web Driver executable. For Firefox browser the Web Driver file name is usually "geckodriver". For Chrome browser the Web Driver file name is usually "chromedriver". For Edge browser the Web Driver file name is usually "msedgedriver.exe".

Place the Web Driver file into the corresponding sub-directory of the program's data directory:

`web_driver_directory`

### Установка веб-драйвера (опционно):

Программа поставляется с предустановленным веб-драйвером для браузера Firefox, поэтому если вы хотите использовать Firefox, он будет работать без каких-либо дополнительных действий. Однако, если вы хотите использовать другой браузер, например Chrome или Edge, вы должны установить соответствующий веб-драйвер вручную, как описано ниже. К тому же, в случае использования Chrome или Edge вы должны будете периодически обновлять веб-драйвер, чтобы его версия совпадала с текущей версией автоматически обновляемого браузера Chrome или Edge.

Установите веб-драйвер для браузера, который вы хотите использовать. Ссылки для загрузки приведены на сайте:

Скачать веб-драйвер

Важно:Для всех браузеров, кроме Firefox, версия файла веб-драйвера должна совпадать с текущей версией вашего браузера.

Откройте скачанный архив и извлеките файл веб-драйвера. Веб-драйвер для браузера Firefox обычно имеет имя "geckodriver". Веб-драйвер для браузера Chrome обычно имеет имя "chromedriver". Веб-драйвер для браузера Edge обычно имеет имя "msedgedriver.exe".

Поместите файл веб-драйвера в соответствующую поддиректорию в директории данных программы:

`web_driver_directory`

### Automatic pedals detection:

Currently, the program supports just one specific type of pedals out of the box - the "Thrustmaster wheel" foot pedals (Thrustmaster 360 SPIDER PC).

If other pedals are used, the program will attempt to recognize them automatically. Just plug the pedals into the PC, run the program, and follow the instructions on the screen. If the pedals are recognized successfully, the information is saved to the file "auto_detected_pedals.txt", and next time the program is run the new pedals will be recognized automatically:

`auto_detected_pedals_file`

Users who use pedals which where successfully recognized by the program, can send the above file to the program's developer so new versions of the program could support these pedals out of the box:

Email

Site

Currently supported pedal roles are "Pause/Play pedal" and "Jump Back pedal". User can assign any role to any pedal, can use both pedals or just one. This is done automatically by running the program and following the instructions on the screen.

(Technically, the auto_detected_pedals.txt file can also be edited manually.)

### Автоматическое распознавание педалей:

В настоящее время программа поддерживает только один конкретный вид педалей, с которыми она работает без дополнительной настройки - это ножные педали "Thrustmaster wheel" (Thrustmaster 360 SPIDER PC).

Если используются другие педали, программа попытается распознать их автоматически. Просто подключите педали к компьютеру, запустите программу и следуйте инструкциям на экране. Если педали будут удачно распознаны, информация будет сохранена в файле "auto_detected_pedals.txt", и при следующем запуске программы новые педали будут распознаны автоматически:

`auto_detected_pedals_file`

Пользователи, использующие педали, успешно распознанные программой, могут отправить вышеуказанный файл разработчику, чтобы последующие версии программы работали с данными педалями без дополнительной настройки:

Email

Сайт

В настоящее время поддерживаются следующие роли педалей: "Педаль Пауза/Воспроизведение" и "Педаль Возврата назад". Любой педали можно назначить любую из этих ролей. Можно использовать обе педали, или только одну. Все это делается автоматически путем запуска программы и следования инструкциям на экране.

(Технически, файл auto_detected_pedals.txt можно также редактировать вручную.)

### Running the program:

If the program was installed using PIP:

`python3 -m pip install --no-cache-dir browserpedals`

then a shortcut ("BrowserPedals" icon) was automatically created on the Desktop and in the Applications menu. In this case the program can be launched using this shortcut, or by right-clicking the video file which we want to open and selecting "BrowserPedals" program from the drop-down menu. Technically, the program "browserpedals.py" or its submodules "usepedals.py" and "detectpedals.py" can also be run as Python scripts from command line:

`python3 browserpedals.py`

### Запуск программы:

Если программа устанавливалась с использованием PIP:

`python3 -m pip install --no-cache-dir browserpedals`

тогда на рабочем столе и в меню приложений для нее был автоматически создан ярлык "BrowserPedals". В этом случае программу можно запустить, используя этот ярлык, или щелкнув правой кнопкой мыши на том видео-файле, который мы хотим открыть, и в выпадающем меню выбрав программу "BrowserPedals". Технически, программу "browserpedals.py" и ее подмодули "usepedals.py" и "detectpedals.py" можно также запустить из командной строки как Python-скрипты:

`python3 browserpedals.py`

### Changing the appearance of the user interface:

The program uses web browser as graphical user interface. The way the interface elements look can be changed by editing the following CSS file:

`ui_appearance_css_file`

### Изменение внешнего вида пользовательского интерфейса:

В качестве графического пользовательского интерфейса программа использует веб-браузер. То, как выглядят элементы этого интерфейса, можно менять, редактируя следующий CSS-файл:

`ui_appearance_css_file`

### Copy subtitles to clipboard:

Important: On Linux, to use this feature instal xclip: `sudo apt-get install xclip`

The following text file contains several options which users can edit to change the way the program behaves:

`options_text_file`

To enable this feature, set the value of the subtitles_to_clipboard option in the options file to 1. To disable this feature, set it to 0.

If this feature is enabled, every time user presses the pedal to Play the video and then presses the pedal to Pause it, subtitle timing data in SRT format is created for the video fragment just played (Play starts the subtitle, Pause ends the subtitle). This SRT data is copied to the clipboard. Then it can be pasted to any text file before corresponding text fragment to make it an SRT subtitle.

User can prepare subtitles in the form of an SRT file for a video as follows:

First, prepare a text file with plain text by typing while listening to the video. For example, you can use this program and pedals to type such file. Or you may use an existing text file if you have one. The main advantage of the described method is that you can select yourself which fragments in the text will be the subtitles. Start from the beginning of the text, choose the text fragment that will be the first subtitle. Add two line breaks at the end of the fragment, so it will be on a separate line. Press the pedal to play the video. When the video reaches the end of the selected fragment of text, press the pedal to pause the video. Place the cursor at the beginning of the text fragment, and select Paste from the mouse's right button menu, or hit Ctrl-V. The time interval of the subtitle in SRT format will be pasted into the text from the clipboard. Then choose the text fragment that will be the second subtitle. Add two line breaks at the end of the fragment, so it will be on a separate line. Press the pedal to play the video. When the video reaches the end of the selected fragment of text, press the pedal to pause the video. Place the cursor at the beginning of the text fragment, and repeat the same steps as for the previous fragment to paste the subtitle SRT data before the text fragment. This way, by continuously playing, pausing, and pasting SRT data, plain text file can be transformed into an SRT subtitle file. You can subdivide the text into subtitles any way you want, by pausing at selected places in the text. The SRT file will look as follows:

`1 00:00:00,100 --> 00:00:01,900 What's up guys? This is the first subtitle. 2 00:00:02,000 --> 00:00:04,266 And this is the second subtitle.`

(hours:minutes:seconds,milliseconds)

Subtitles are assigned numbers starting from number 1. To continue subtitles from any given number, before pressing Pause pedal and pasting the subtitle data, copy previous number to the clipboard. For example, if you want the next subtitle to have number 5, copy number 4 to the clipboard, and only after that press Pause pedal and paste the subtitle data.

Sometimes, there may be a long silent period in the video. When you press Pause pedal after such silent period ends, the clipboard will contain subtitle data for this silent period. But we don't want that. In this case, after you have have pressed Pause pedal at the end of the silent period, press Jump Back pedal. Then press Play pedal, wait for the speech to start, and press Pause pedal. After that, as usual, continue playing, listening to the speech, pausing, and pasting time intervals at the start of subtitles. The pasted subtitle timing will have correct number and will start when the silence ended. The silent subtitle will be dropped.

If the value of feature subtitles_to_clipboard is set to -1, just timestamps are copied to clipboard every time Pause pedal is pressed, instead of copying subtitle data. In this case periodic_timestamp_format option specifies the format of the timestamp string which is copied to the clipboard during each pause. Set the value of the periodic_timestamp_format option in the options file to a Python format string, for example it can contain format elements such as {SS:04d} - in this string you can use variables SS (time in seconds), MM (time in minutes), hh (hours), mm (minutes), ss (seconds), uu (milliseconds).

### Копирование субтитров в буфер обмена:

Важно: В Linux, чтобы использовать данную функцию, установите xclip: `sudo apt-get install xclip`

Следующий текстовый файл содержит ряд опций, которые пользователь может менять, чтобы корректировать поведение программы:

`options_text_file`

Чтобы включить данную функцию, в файле опций поменяйте значение value опции subtitles_to_clipboard на 1. Чтобы отключить данную функцию, поменяйте значение 1 на 0.

Если данная опция включена, каждый раз, когда пользователь нажимает педаль для Воспроизведения видео, а затем нажимает педаль для Паузы видео, для только что проигранного фрагмента видео создаются параметры для субтитра в SRT-формате (Воспроизведение начинает субтитр, Пауза заканчивает субтитр), и эти SRT-данные копируются в буфер обмена. После этого их можно вставить в любой текстовый файл перед соответствующим фрагментом текста, что превратит фрагмент в SRT-субтитр.

Субтитры для видео в форме SRT-файла можно подготовить следующим образом:

Для начала подготовьте текстовый файл с простым текстом, напечатав его во время прослушивании видео. Например, можно напечатать такой файл при помощи данной программы и педалей. Или можете использовать существующий текстовый файл, если таковой имеется. Главное преимущество описываемого метода в том, что вы сами можете выбирать, какие фрагменты текста будут субтитрами. Начните с начала текста, выберите фрагмент, который станет первым субтитром. Добавьте две новые строки в конце фрагмента, чтобы он оказался на отдельной строке. Нажмите педаль, чтобы видео заиграло. Когда видео доиграет до конца выбранного фрагмента текста, нажмите педаль, чтобы видео встало на паузу. Установите курсор на начало текстового фрагмента и выберите Вставить в меню правой кнопки мыши, или нажмите клавиши Ctrl-V. Временной интервал для субтитра в формате SRT будет вставлен в текст из буфера обмена. Далее, выберите фрагмент текста, который будет вторым субтитром. Добавьте две новые строки в конце фрагмента, чтобы он оказался на отдельной строке. Нажмите педаль, чтобы видео заиграло. Когда видео доиграет до конца выбранного фрагмента текста, нажмите педаль, чтобы видео встало на паузу. Установите курсор на начало текстового фрагмента, и повторите все так же, как в случае с первым фрагментом, чтобы перед текстовым фрагментом вставить SRT-данные для субтитра. Таким образом, последовательно запуская видео, останавливая видео, и вставляя в текст SRT-данные, файл с непрерывным текстом может быть преобразован в файл субтитров в формате SRT. Вы можете разбивать текст на субтитры так, как вам угодно, нажимая на педаль Паузы в выбранных местах в тексте. SRT-файл будет выглядеть следующим образом:

`1 00:00:00,100 --> 00:00:01,900 Ну что, друзья? Вот вам и первый субтитр. 2 00:00:02,000 --> 00:00:04,266 Ну а это второй.`

(часы:минуты:секунды,миллисекунды)

Субтитрам присваиваются номера, начиная с 1. Чтобы продолжить субтитры с любого заданного номера, перед тем, как нажать педаль паузы и вставить данные из буфера обмена в текст, скопируйте предыдущий номер в буфер обмена. Например, если вы хотите, чтобы следующий субтитр имел номер 5, скопируйте цифру 4 в буфер обмена, и только после этого нажмите на педаль паузы и вставьте данные для субтитра.

Иногда по ходу видео может возникнуть продолжительный период молчания. Когда вы нажимаете педаль паузы в конце такого периода молчания, буфер обмена будет содержать данные субтитра, соответствующие этому периоду тишины. Но это совсем не то, что нам нужно. В таком случае, после того, как вы нажали педаль Паузы в конце периода молчания, нажмите педаль Возврата назад. Затем нажмите педаль Воспроизведения, чтобы видео заиграло, дождитесь начала речи и нажмите педаль Паузы. После этого, как обычно, продолжайте запускать видео, останавливать его, и вставлять в текст временные интервалы в начала субтитров. Вставленный временной интервал для субтитра будет иметь правильный номер и будет начинаться после завершения периода молчания. Субтитр с тишиной будет пропущен.

Если значение опции subtitles_to_clipboard установлено равным -1, при каждом нажатии педали Пауза вместо данных субтитра в буфер обмена копируются просто текущие моменты времени видео. В этом случае опция periodic_timestamp_format задает формат строки с текущим временем, которая копируется в буфер обмена после каждой паузы. В качестве значения поля value опции periodic_timestamp_format должна выступать строка формата из языка Python. Например, она может содержать элементы формата типа {SS:04d} - в этой строке можно использовать переменные SS (время в секундах), MM (время в минутах), hh (часы), mm (минуты), ss (секунды), uu (миллисекунды).

### Periodic pause:

Important: On Linux, to use this feature instal xclip: `sudo apt-get install xclip`

The following text file contains several options which users can edit to change the way the program behaves:

`options_text_file`

Sometimes there is a requirement that the text typed during listening to a video/audio should also contain timestamps inserted into the text periodically after the video/audio plays for some time. For example, time markers should be inserted into the text every minute. Following options serve this purpose.

If the feature pause_period_sec is enabled, the video/audio periodically pauses at certain time points in the video. When pressing Play after each such pause, current time point in the video/audio is copied to the clipboard, so the user can paste it into any text file. The string copied to the clipboard will have the format specified in the next option of the options file called periodic_timestamp_format.

To enable this feature, set the value of the pause_period_sec option in the options file to desired time interval between pauses, in seconds, possibly with a fractional part. To disable this feature, set the value to 0.

If the previous feature called pause_period_sec is enabled, the option periodic_timestamp_format specifies the format of the timestamp string which is copied to the clipboard after each periodic pause. Set the value of the periodic_timestamp_format option in the options file to a Python format string, for example it can contain format elements such as {SS:04d} - in this string you can use variables SS (time in seconds), MM (time in minutes), hh (hours), mm (minutes), ss (seconds), uu (milliseconds).

If the value of feature subtitles_to_clipboard is set to -1, timestamps are copied to the clipboard also every time Pause pedal is pressed.

### Периодическая пауза:

Важно: В Linux, чтобы использовать данную функцию, установите xclip: `sudo apt-get install xclip`

Следующий текстовый файл содержит ряд опций, которые пользователь может менять, чтобы корректировать поведение программы:

`options_text_file`

Иногда ставится требование, чтобы текст, напечатанный во время прослушивания видео/audio, также содержал временные метки, периодически вставляемые в текст каждый раз, когда в видео/audio проходит определенное время. Например, нужно вставлять временный маркеры в текст каждую минуту. Следующие опции служат этой цели.

Если опция pause_period_sec включена, видео/аудио будет периодически вставать на паузу в определенные моменты текущего времени видео/аудио. При нажатии педали Воспроизведения после каждой такой паузы текущий момент времени видео/аудио будет скопирован в буфер обмена, чтобы пользователь мог вставить его в любой текстовый файл. Строка, скопированная в буфер обмена, будет иметь формат, заданный в следующей опции файла опций под названием periodic_timestamp_format.

Чтобы включить данную функцию, в файле опций поменяйте значение value опции subtitles_to_clipboard на величину требуемого интервала времени между паузами, в секундах, возможно с дробной частью. Чтобы отключить данную функцию, установите значение 0.

Если включена предыдущая опция pause_period_sec (периодическая пауза), то опция periodic_timestamp_format задает формат строки с текущим временем, которая копируется в буфер обмена после каждой периодической паузы. В качестве значения поля value опции periodic_timestamp_format должна выступать строка формата из языка Python. Например, она может содержать элементы формата типа {SS:04d} - в этой строке можно использовать переменные SS (время в секундах), MM (время в минутах), hh (часы), mm (минуты), ss (секунды), uu (миллисекунды).

Если значение опции subtitles_to_clipboard установлено равным -1, то текущие моменты времени видео будут копироваться в буфер обмена также при каждом нажатии педали Паузы.